@@ -1,10 +1,10 @@
-# @(#)$Id: ResultSource.pm 321 2011-11-30 00:01:49Z pjf $
+# @(#)$Id: ResultSource.pm 327 2011-12-03 18:37:37Z pjf $
 
 package File::DataClass::ResultSource;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 321 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 327 $ =~ /\d+/gmx );
 
 use File::DataClass::Constants;
 use Moose;
@@ -25,7 +25,7 @@ has 'resultset_class'      => is => 'ro', isa => 'ClassName',
    default                 => q(File::DataClass::ResultSet);
 has 'schema'               => is => 'ro', isa => 'Object',
    required                => TRUE, weak_ref => TRUE,
-   handles                 => [ qw(exception_class path storage) ];
+   handles                 => [ qw(path storage) ];
 
 sub resultset {
    my $self = shift;
@@ -51,7 +51,7 @@ File::DataClass::ResultSource - A source of result sets for a given schema
 
 =head1 Version
 
-0.7.$Revision: 321 $
+0.7.$Revision: 327 $
 
 =head1 Synopsis
 
